#include <exec/types.h>
#include <exec/libraries.h>
#include <libraries/dos.h>
#include <intuition/intuition.h>
#include <graphics/gfxbase.h>
#include <proto/all.h>
#include <string.h>

int CXBRK(void) { return(0); }		/* Disable Lattice CTRL/C handling */
int chkabort(void) { return(0); }	/* really */

#include "cwritelibbase.h"
#include "cwritelib.h"

void main(int,char**);
struct IntuitionBase *IntuitionBase;
struct GfxBase *GfxBase;
struct CwrlibBase *CwrlibBase;
struct CwrData *cdata;

UBYTE screentitle[] = "Test program for cwrite.library";
struct Window *TheWindow;

UBYTE cursortype = CURSORTYPE_FAST;

static void cleanup(char *string)
{
	int returncode = RETURN_OK;

/* Write string, if it is there, and set the returncode to ERROR */
	if(string)
	{
		Write(Output(),"Error: ",7);
		Write(Output(),string,strlen(string));
		returncode = RETURN_FAIL;
	}
/* Close everything down.. */
	if(TheWindow)	CWriteCloseWindow(TheWindow);
	if(cdata)	CWriteFree(cdata);
	if(CwrlibBase)	CloseLibrary((struct Library*)CwrlibBase);
/* and exit to CLI or WorkBench */
	Exit(returncode);
}

static int Showfile(char *filename)
{
	register int i;
	UBYTE out[256];
	BPTR fd;

/* Are we able to open the file?	*/
	if(fd = Open(filename,MODE_OLDFILE))
	{
/* Yes, so we will first clear the screen with a "<ESC>c" command */
		CWrite(cdata,"c",2);
		do
		{
/* Write the same amount of chars we receive from Read() to CWrite() */
			if(i = Read(fd,(char*)&out,255))
				CWrite(cdata,out,i);
		} while(i == 255);
/* No more characters. Close file, and return that file was read ok. */
		Close(fd);
		return(TRUE);
	}
/* File could not be opened, so we return a FALSE */
	else
		return(FALSE);
}

void main(int argc, char **argv)
{
	int height = 200;

	if(argc==0)	/* Started from Workbench! */
		cleanup(NULL);
	if(argc < 2)
		cleanup("\nUsage: Testlib Filename <cursortype>\n");

/* Open cwrite.library */
	if(!(CwrlibBase=(struct CwrlibBase *)OpenLibrary("cwrite.library",0)))
		cleanup("Can't open cwrite.library\n");

/* Use the pointers in CwrlibBase for gfx and intuition */
	GfxBase = (struct GfxBase*)CwrlibBase->GfxLib;
	IntuitionBase = (struct IntuitionBase*)CwrlibBase->IntLib;

/* If this should be a PAL system, we'll change the window height to 256: */
	if(GfxBase->DisplayFlags & PAL)
		height = 256;

/* Allocate memory for our CwrData structure */
	cdata = CWriteAlloc();
	if(!cdata)
		cleanup("Can't allocate memory for CWrite functions!\n\7");

/* Open a screen and window for output with CWrite() */
	TheWindow = CWriteOpenWindow(screentitle,640,height,4,0);
/* The screen may be optained from the window pointer, like this: */
/*	TheScreen = TheWindow->WScreen;*/
	if(!TheWindow)
		cleanup("Can't open the window or screen!\n\7");

/* We don't need to use CWriteSetColors() here, as the library automatically
   sets the colors upon opening the window and screen.
   This is just an example on how you should call the routine, if you should
   decide to open the window and screen by yourself. */
/*	CWriteSetColors(TheWindow);*/

/* Initialize our CwrData structure for use with the CWrite() function. */
	CWriteInit(cdata,TheWindow);

/* If there are 2 args, the second argument is the cursortype.. */
	if(argc == 3)
	{
		switch(argv[2][0])
		{
			case '0':	/* None	*/
				cursortype = CURSORTYPE_NONE;
				break;
			case '1':	/* Fast	*/
				cursortype = CURSORTYPE_FAST;
				break;
			case '2':	/* Slow	*/
				cursortype = CURSORTYPE_SLOW;
				break;
			default:
				cursortype = CURSORTYPE_FAST;
				break;
		}
	}
	CWriteCursorType(cdata,cursortype);

/* Show the filename that was written as the first argument. */
	if(!Showfile(argv[1]))
		cleanup("Unable to open file!\n\7");
	else
		Delay(100);	/* Wait for 2 seconds..	*/

/* Clean up everything, and exit properly. */
	cleanup(NULL);
}
